@@ -27,7 +27,7 @@ import quip.field_builder as fb
 from argparse import RawTextHelpFormatter
 from colorama import Fore, Style, init
 
-version = "1.4.2"
+version = "1.4.4"
 UPDATE_ACTION = ["update", "u", "up"]
 FIELD_ACTION = ["fields", "f", "fi"]
 ICON_ACTION = ["icon", "resize-icon", "ri", "resize"]
@@ -37,6 +37,7 @@ BOOTSTRAP_ACTION = ["bootstrap", "bs", "boot", "bst", "baseline"]
 DOWNLOAD_ACTION = ["download", "pull"]
 UPLOAD_ACTION = ["upload", "push"]
 BUILD_ACTION = ["build", "b", "dist", "zip"]
+CLEAN_ACTION = ["clean", "clear"]
 init()
 
 def cprint(text, color, end='\n'):
@@ -124,8 +125,13 @@ class Quip:
         parser_icon.add_argument('--generate', '-g', action='store_true',
                              help='generate new icon')
 
+        parser_icon = subparsers.add_parser('clean', aliases=CLEAN_ACTION[1:], help='Clears the dist folders')
+        parser_icon.add_argument('name', nargs="?", help='name of the project')
+
         parser_icon = subparsers.add_parser('config', help='show the configuration')
 
+
+
         args = parser.parse_args()
         print(args)
 
@@ -184,19 +190,18 @@ class Quip:
             self.create_icon_safe()
         elif action in UPLOAD_ACTION:
             if not self.args.template:
-                logging.error("This action only possible with --template option. For extensions use 'uip push' command.")
-                sys.exit(1)
-            self.upload_template()
+                self.run_uip("push_all")
+            else:
+                self.upload_template()
         elif action in DOWNLOAD_ACTION:
             if not self.args.template:
-                logging.error("This action only possible with --template option. For extensions use 'uip pull' command.")
-                sys.exit(1)
-
-            if os.path.exists(self.project_name) or self.in_project_folder:
-                self.download_template()
+                self.run_uip("pull")
             else:
-                self.bootstrap_template(ask_for_upload=False)
-                self.download_template()
+                if os.path.exists(self.project_name) or self.in_project_folder:
+                    self.download_template()
+                else:
+                    self.bootstrap_template(ask_for_upload=False)
+                    self.download_template()
             self.dump_fields(write=True)
         elif action == "build":
             if not self.args.template:
@@ -207,6 +212,9 @@ class Quip:
             if not self.uip_global_config.get("new", False):
                 QuipGlobalConfig().check_config(self.uip_global_config)
             sys.exit(0)
+        elif action in CLEAN_ACTION:
+            self.clean_project()
+            sys.exit(0)
 
     def set_global_configs(self, project_name, config_path=None):
         if config_path is not None:
@@ -361,6 +369,22 @@ class Quip:
             sys.exit(1)
 
         shutil.rmtree(self.project_name)
+    
+    def clean_project(self):
+        for folder in ["build", "dist", "temp"]:
+            folder_path = self.join_path(folder)
+        
+            if os.path.exists(folder_path):
+                cprint(f"Deleting content of {folder_path}", color="blue")
+                for filename in os.listdir(folder_path):
+                    file_path = os.path.join(folder_path, filename)
+                    try:
+                        if os.path.isfile(file_path) or os.path.islink(file_path):
+                            os.unlink(file_path)
+                        elif os.path.isdir(file_path):
+                            shutil.rmtree(file_path)
+                    except Exception as e:
+                        print('Failed to delete %s. Reason: %s' % (file_path, e))
 
     def clone_project(self, from_project_path, all_files=False, exclude_list=None):
         if not os.path.exists(from_project_path):
@@ -434,7 +458,6 @@ class Quip:
         if len(uac_pass) == 0:
             logging.debug("Using password from config")
             uac_pass = self._global_conf_defaults.get("uac_password")
-            logging.debug(f"Password is {uac_pass}")
 
         uac_url = self._global_conf_uip.get("url", "http://localhost:8080/uc")
         template_url = uac_url + "/resources/universaltemplate/importtemplate"
@@ -660,6 +683,43 @@ class Quip:
             logging.error(f"ERROR: Command is {command}")
             logging.error(f"ERROR: Return code is {command.returncode}")
             sys.exit(command.returncode)
+    
+    def run_uip(self, action):
+        need_pass = False
+        if action in ["push_all", "push"]:
+            additional_params = "-a" if action == "push_all" else ""
+            command = f'''uip push {additional_params} -i {self._global_conf_uip["url"]} -u {self._global_conf_uip["userid"]}'''
+            need_pass = True
+        elif action == "pull":
+            need_pass = True
+            command = f'''uip pull -i {self._global_conf_uip["url"]} -u {self._global_conf_uip["userid"]}'''
+
+        if need_pass:
+            uac_pass = getpass(prompt=f'''Enter password for {self._global_conf_uip["userid"]}: ''')
+            if len(uac_pass) == 0:
+                logging.debug("Using password from config")
+                uac_pass = self._global_conf_defaults.get("uac_password")
+            os.environ["UIP_PASSWORD"] = uac_pass
+        
+        logging.info(f"Initializing the extension with command {command}")
+        cprint(command, color="yellow")
+        result = subprocess.run(command, shell=True, stderr=subprocess.PIPE, stdout=subprocess.PIPE, universal_newlines=True)
+        if result.returncode != 0:
+            logging.error("UIP command failed.")
+            logging.error(f"ERROR: Command is {command}")
+            logging.error(f"ERROR: Return code is {command.returncode}")
+            sys.exit(command.returncode)
+        else:
+            cprint(f"======= UIP Output =======", color="yellow")
+            for line in result.stdout.splitlines():
+                if line.lower().startswith("success"):
+                    cprint(line, color="green")
+                elif line.lower().find("error") > 0:
+                    cprint(line, color="red")
+                else:
+                    print(line)
+            cprint(f"==============", color="yellow")
+            
 
     def update_extension_yaml(self, project_name):
         logging.info("Updating extension.yml file")
@@ -955,11 +1015,6 @@ class QuipGlobalConfig:
                         cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ut-baseline.git\n", color="green")
 
 
-
-            
-        
-
-
 class MyDumper(yaml.SafeDumper):
     # HACK: insert blank lines between top-level objects
     # inspired by https://stackoverflow.com/a/44284819/3786245
